API Reference
=============

.. currentmodule:: scalib


.. autosummary::
   :recursive:
   :nosignatures:
   :toctree: api

   metrics
   preprocessing
   modeling
   attacks
   postprocessing
   config
   tools

